@@ -87,7 +87,8 @@ def import_content(session, commitevery=10):
         except VCSException, ex:
             session.error(str(ex))
             continue
-        import_vcsrepo_content(session, repohdlr, vcsrepo, commitevery=10)
+        import_vcsrepo_content(session, repohdlr, vcsrepo,
+                               commitevery=commitevery)
 
 
 def import_vcsrepo_content(session, repohdlr, vcsrepo, commitevery=10):
