@@ -380,6 +380,30 @@ class DeletedVersionContent(AnyEntity):
     def head(self):
         return self.file.branch_head(self.rev.branch)
 
+    def previous_version(self, branch=_MARKER):
+        if branch is _MARKER:
+            branch = self.rev.branch
+        rset = self._cw.execute('Any PV,R,PVR,VF ORDERBY PVR DESC LIMIT 1 '
+                                'WHERE PV from_revision R, R revision PVR, '
+                                'R branch %(b)s, PV content_for VF, '
+                                'R revision < %(r)s, VF eid %(vf)s',
+                                {'r': self.rev.revision, 'b': branch,
+                                 'vf': self.file.eid})
+        if rset:
+            return rset.get_entity(0, 0)
+
+    def next_version(self, branch=_MARKER):
+        if branch is _MARKER:
+            branch = self.rev.branch
+        rset = self._cw.execute('Any NV,R,NVR,VF ORDERBY NVR ASC LIMIT 1 '
+                                'WHERE NV from_revision R, R revision NVR, '
+                                'R branch %(b)s, NV content_for VF, '
+                                'R revision > %(r)s, VF eid %(vf)s',
+                                {'r': self.rev.revision, 'b': branch,
+                                 'vf': self.file.eid})
+        if rset:
+            return rset.get_entity(0, 0)
+
     # < 0.7 bw compat properties
     @property
     def revision(self):
