@@ -106,10 +106,6 @@ class ServerStartupHook(hook.Hook):
     on the system source sql generator
     """
     __regid__ = 'vcsfile.serverstartuphook'
-    __select__ = hook.Hook.__select__ & (
-        configuration_values('import-revision-content', True)
-        | configuration_values('repository-import', True)
-        )
 
     events = ('server_startup',)
     def __call__(self):
@@ -126,16 +122,11 @@ class ServerStartupHook(hook.Hook):
             session = repo.internal_session()
             try:
                 reposrset = session.execute(
-                    'Any R, RT, RLC, RSU, RP WHERE R is Repository, '
-                    'R type "mercurial", NOT R local_cache NULL, '
-                    'R type RT, R local_cache RLC, '
-                    'R source_url RSU, R path RP')
+                    'Any R, RT, RLC, RSU, RP, RIRC WHERE R is Repository, '
+                    'R type "mercurial", NOT (R local_cache NULL AND R path NULL),'
+                    'R type RT, R local_cache RLC, R source_url RSU, R path RP,'
+                    'R import_revision_content RIRC, R cw_source S, S name "system"')
                 for vcsrepo in reposrset.entities():
-                    # XXX when this will be available, filter according to
-                    # source in the rql query instead of the test below
-                    # used to discard repository from external sources
-                    if vcsrepo.cw_metainformation()['source']['uri'] != 'system':
-                        continue
                     try:
                         repohdlr = bridge.repository_handler(vcsrepo)
                     except bridge.VCSException, ex:
@@ -145,12 +136,14 @@ class ServerStartupHook(hook.Hook):
                         repo.exception('error while retreiving handler for %s',
                                        vcsrepo.eid)
                         continue
-                    try:
-                        repohdlr.pull_or_clone_cache(vcsrepo.source_url)
-                    except Exception:
-                        repohdlr.exception(
-                            'error while updating local cache of repository %s',
-                            vcsrepo.eid)
+                    if (repo.config['repository-import'] or vcsrepo.import_revision_content) \
+                           and vcsrepo.local_cache is not None:
+                        try:
+                            repohdlr.pull_or_clone_cache(vcsrepo.source_url)
+                        except Exception:
+                            repohdlr.exception(
+                                'error while updating local cache of repository %s',
+                                vcsrepo.eid)
                     if repo.config['repository-import']:
                         bridge.import_vcsrepo_content(
                             session, repohdlr, vcsrepo,
@@ -323,7 +316,7 @@ class CloneRepoAfterAddHook(hook.Hook):
         if not vcsrepo.local_cache:
             return
         # XXX rmdir on rollback
-        if (self._cw.vreg.config['import-revision-content']
+        if (vcsrepo.import_revision_content
             or self._cw.vreg.config['repository-import']):
             clone_to_local_cache(vcsrepo)
 
@@ -346,7 +339,7 @@ class UpdateRepositoryHook(hook.Hook):
             and not vcsrepo.path and not vcsrepo.local_cache):
             # XXX rmdir on rollback
             set_local_cache(vcsrepo)
-            if (self._cw.vreg.config['import-revision-content']
+            if (vcsrepo.import_revision_content
                 or self._cw.vreg.config['repository-import']):
                 clone_to_local_cache(vcsrepo)
 
