@@ -9,7 +9,7 @@ _ = unicode
 
 from yams.buildobjs import (DEFAULT_ATTRPERMS,
                             EntityType, RelationDefinition,
-                            String, Int, Bytes)
+                            String, Int, Boolean, Bytes)
 from cubicweb.schema import RRQLExpression
 
 PRIVATE_ATTRPERMS = DEFAULT_ATTRPERMS.copy()
@@ -53,6 +53,9 @@ class Repository(EntityType):
     encoding = String(default='utf-8', maxsize=20, required=True,
                       description=_('encoding used for the repository (e.g.'
                                     ' for file path and check-in comments)'))
+    import_revision_content = Boolean(default=True,
+                                      description=_('import contents of files touched by a revision. '
+                                                    'It may cause performance issue when scaling.'))
 
 
 class Revision(EntityType):
